/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.processor;

import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import de.ozgcloud.apilib.vorgang.OzgCloudVorgangService;
import de.ozgcloud.apilib.vorgang.grpc.GrpcOzgCloudVorgangService;
import de.ozgcloud.apilib.vorgang.grpc.OzgCloudVorgangMapper;
import de.ozgcloud.apilib.vorgang.grpc.OzgCloudVorgangQueryMapper;
import de.ozgcloud.apilib.vorgang.grpc.OzgCloudVorgangStubMapper;
import de.ozgcloud.vorgang.vorgang.VorgangServiceGrpc;
import net.devh.boot.grpc.client.inject.GrpcClient;

@Configuration
public class ProcessorManagerConfiguration {

	public static final String PROCESSOR_EVENT_LISTENER_NAME = "processorManager_ProcessorEventListener";
	public static final String PROCESSOR_PROPERTIES_NAME = "processorManager_ProcessorProperties";
	public static final String PROXY_PROPERTIES_NAME = "processorManager_ProxyProperties";
	public static final String AKTENNOTIZ_FACTORY_NAME = "processorManager_AktennotizFactory";
	public static final String VORGANG_MAPPER_NAME = "processorManager_VorgangMapper";

	public static final String VORGANG_SERVICE_NAME = "processorManager_VorgangService";
	public static final String PROCESSOR_SERVICE_NAME = "processorManager_ProcessorService";
	public static final String RESULT_SERVICE_NAME = "processorManager_ResultService";

	public static final String OZGCLOUD_VORGANG_SERVICE_NAME = "processorManager_OzgCloudVorgangService";

	public static final String GRPC_VORGANG_SERVICE_ADDRESS = "vorgang-manager";

	@GrpcClient(GRPC_VORGANG_SERVICE_ADDRESS)
	private VorgangServiceGrpc.VorgangServiceBlockingStub vorgangServiceStub;

	@ConditionalOnProperty(prefix = "ozgcloud.processors[0]", name = "address")
	@Bean(OZGCLOUD_VORGANG_SERVICE_NAME) // NOSONAR
	OzgCloudVorgangService grpcOzgCloudCommandService(OzgCloudVorgangMapper vorgangMapper, OzgCloudVorgangStubMapper vorgangStubMapper,
			OzgCloudVorgangQueryMapper vorgangQueryMapper, ProzessorManagerCallContextProvider contextProvider) {
		return new GrpcOzgCloudVorgangService(vorgangServiceStub, vorgangMapper, vorgangStubMapper, vorgangQueryMapper, contextProvider);
	}
}
