/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.processor.processor;

import java.util.List;
import java.util.Set;

import jakarta.validation.constraints.NotNull;

import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Configuration;
import org.springframework.validation.annotation.Validated;

import de.ozgcloud.processor.ProcessorManagerConfiguration;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;
import lombok.Singular;
import lombok.ToString;

@ToString
@Getter
@Setter
@Configuration(ProcessorManagerConfiguration.PROCESSOR_PROPERTIES_NAME) // NOSONAR
@ConfigurationProperties(prefix = "ozgcloud")
@Validated
@Builder
@NoArgsConstructor
@AllArgsConstructor
class ProcessorProperties {

	@Singular
	private List<Processor> processors;

	@ToString
	@Getter
	@Setter
	@Builder
	@Validated
	@NoArgsConstructor
	@AllArgsConstructor
	static class Processor {

		/**
		 * Name of the processor
		 */
		@NotNull
		private String name;

		/**
		 * List of engine names and form IDs for which the processor is responsible.
		 */
		@Singular
		private Set<Form> forms;

		/**
		 * URL of the external processor
		 */
		@NotNull
		private String address;
	}

	@ToString
	@Getter
	@Setter
	@Builder
	@NoArgsConstructor
	@AllArgsConstructor
	static class Form {

		@NotNull
		private String formEngineName;

		private String formId;
	}
}
