/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.processor.result;

import jakarta.validation.Valid;

import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Service;
import org.springframework.validation.annotation.Validated;

import de.ozgcloud.apilib.alfa.AlfaService;
import de.ozgcloud.apilib.vorgang.OzgCloudVorgangIdMapper;
import de.ozgcloud.processor.ProcessorManagerConfiguration;
import de.ozgcloud.processor.processor.ProcessorResult;
import lombok.RequiredArgsConstructor;

@Service(ProcessorManagerConfiguration.RESULT_SERVICE_NAME) // NOSONAR
@RequiredArgsConstructor
@Validated
public class ResultService {

	private final AlfaService alfaService;
	private final OzgCloudVorgangIdMapper vorgangIdMapper;
	@Qualifier(ProcessorManagerConfiguration.AKTENNOTIZ_FACTORY_NAME) // NOSONAR
	private final AktennotizFactory aktennotizFactory;

	public void processResult(@Valid ProcessorResult result) {
		if (Action.CREATE_AKTENNOTIZ == result.getAction()) {
			addAktenNotiz(aktennotizFactory.createFrom(result));
		}
	}

	public void processError(Throwable cause, String vorgangId) {
		if (cause instanceof ProcessorTechnicalException exception) {
			addAktenNotiz(
					aktennotizFactory.createErrorAktennotiz(exception.getVorgangId(), exception.getProcessorName(), exception.getExceptionId()));
		} else {
			addAktenNotiz(aktennotizFactory.createErrorAktennotizBuilder(vorgangId)
					.text("Es ist eine Fehler bei der Verarbeitung des Vorganges aufgetreten").build());
		}
	}

	void addAktenNotiz(Aktennotiz aktennotiz) {
		alfaService.addAktenNotiz(vorgangIdMapper.fromString(aktennotiz.getVorgangId()), aktennotiz.getText());
	}

}
