/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.processor.vorgang;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mapstruct.factory.Mappers;

import de.ozgcloud.apilib.vorgang.OzgCloudEingang;
import de.ozgcloud.apilib.vorgang.OzgCloudVorgangTestFactory;

class ProcessorVorgangMapperTest {

	private ProcessorVorgangMapper mapper = Mappers.getMapper(ProcessorVorgangMapper.class);

	@Nested
	class TestMapVorgang {
		@Test
		void shouldMapAllField() {
			var mapped = mapper.mapVorgang(OzgCloudVorgangTestFactory.create());

			assertThat(mapped).usingRecursiveComparison().isEqualTo(VorgangTestFactory.create());
		}

		@Test
		void shouldBeAbleToMapPoorEingang() {
			var mapped = mapper.mapVorgang(OzgCloudVorgangTestFactory.createBuilder()
					.clearEingangs().eingang(OzgCloudEingang.builder().build()).build());

			assertThat(mapped).isNotNull();
		}
	}

}
