/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.processor.vorgang;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;

import de.ozgcloud.apilib.vorgang.OzgCloudVorgang;
import de.ozgcloud.apilib.vorgang.OzgCloudVorgangService;
import de.ozgcloud.apilib.vorgang.OzgCloudVorgangTestFactory;

class VorgangServiceTest {

	@InjectMocks
	private VorgangService service;

	@Mock
	private OzgCloudVorgangService ozgCloudService;
	@Mock
	private ProcessorVorgangMapper mapper;

	@Nested
	class TestGetVorgang {

		private OzgCloudVorgang ozgCloudVorgang = OzgCloudVorgangTestFactory.create();
		private Vorgang vorgang = VorgangTestFactory.create();

		@BeforeEach
		void init() {
			when(ozgCloudService.getById(any())).thenReturn(ozgCloudVorgang);
			when(mapper.mapVorgang(any())).thenReturn(vorgang);
		}

		@Test
		void shouldCallOzgCloudService() {
			service.getVorgang(VorgangTestFactory.ID);

			verify(ozgCloudService).getById(OzgCloudVorgangTestFactory.ID);
		}

		@Test
		void shouldCallMapper() {
			service.getVorgang(VorgangTestFactory.ID);

			verify(mapper).mapVorgang(ozgCloudVorgang);
		}

		@Test
		void shouldReturnMappedVorgang() {
			var result = service.getVorgang(VorgangTestFactory.ID);

			assertThat(result).isSameAs(vorgang);
		}
	}
}
